Set-Location -Path "$PSScriptRoot"

$Result = 0

$OtherAppPath = "${env:SystemRoot}\PrintDialog\appxmanifest.xml"

Get-AppxPackage | Format-Table InstallLocation -AutoSize | Out-String -Stream -Width 4096 | ForEach-Object -Begin {$arrExistApps = @()} -Process {

    $_ = $_.trim()

    if(!([string]::IsNullOrEmpty("$_"))){

        if(Test-Path "$_"){
            $arrExistApps+=$_
        } 
    }
}

"***** Installed Apps List *****" | Out-File -FilePath RegAppxLog.txt
$arrExistApps | Out-File -Append -Width 4096 -FilePath RegAppxLog.txt
"ExistApps = " + $arrExistApps.Length | Out-File -Append -FilePath RegAppxLog.txt


"***** Installing Apps *****" | Out-File -Append -FilePath RegAppxLog.txt

$arrInstApps = @()

Get-ChildItem "C:\Windows\SystemApps\*\AppxManifest.xml", "$OtherAppPath" | Format-Table FullName -AutoSize | Out-String -Stream -Width 4096 | ForEach-Object -Process {

    $_ = $_.trim()

    if(!([string]::IsNullOrEmpty("$_"))){

        if(Test-Path "$_"){

            $Flg_Installed = $FALSE

            foreach($AppPath in $arrExistApps){

                $AppPath = $AppPath + "\AppxManifest.xml"

                if("$_" -eq "$AppPath"){
                     $Flg_Installed = $TRUE
                    break
                }
            }

            if(!($Flg_Installed)){
                Add-AppxPackage -Register -DisableDevelopmentMode "$_"
                $arrInstApps += Split-Path -Parent $_

                $strLog = "[Inst] "

            }else{
                $strLog = "[Skip] "
            }

            $strLog +  "$_" | Out-File -Append -Width 4096 -FilePath RegAppxLog.txt

        }
    }
}

"InstApps = " + $arrInstApps.Length | Out-File -Append -FilePath RegAppxLog.txt


"***** Check Apps *****" | Out-File -Append -FilePath RegAppxLog.txt

Get-AppxPackage | Format-Table InstallLocation -AutoSize | Out-String -Stream -Width 4096 | ForEach-Object -Begin {$arrExistApps = @()} -Process {

    $_ = $_.trim()

    if(!([string]::IsNullOrEmpty("$_"))){

        if(Test-Path "$_"){
            $arrExistApps+=$_
        } 
    }
}

foreach($InstAppPath in $arrInstApps){

    $Flg_Installed = $FALSE

    foreach($ExistAppPath in $arrExistApps){

        if("$InstAppPath" -eq "$ExistAppPath"){
            $Flg_Installed = $TRUE
            break
        }
    }

    if(($Flg_Installed)){
        $strLog = "[OK] "
    }else{
        $strLog = "[NG] "
        $Result = -1
    }

    $strLog + "$InstAppPath" | Out-File -Append -Width 4096 -FilePath RegAppxLog.txt

}

"CheckApps = " + $arrInstApps.Length | Out-File -Append -FilePath RegAppxLog.txt
"Result = " + $Result | Out-File -Append -FilePath RegAppxLog.txt

exit $Result
